==> dbd-dark-dashboard-1.6.62.tgz: package/README.md <==
# Important

**This package has been deprecated**

This theme is no longer supported. Please use dbd-soft-ui Theme instead:<br/>https://www.npmjs.com/package/dbd-soft-ui


---


![Banner](./DarkBanner.png)

<p align="center"><img src="https://nodei.co/npm/dbd-dark-dasboard.png"></p>
<p align="center"><a href="https://discord.gg/Nkc8MWxHRD"> <img src="https://discordapp.com/api/guilds/803034737261936670/widget.png" alt="Discord server"/></a></p>

# Discord-Dashboard Dark Theme

- Simple Discord-Dashboard theme
- Easy to customize
- Easy configuration
- Community support

# Preview

![image1](https://i.imgur.com/33sk9Gi.png)
![image2](https://imgur.com/2Lu0dtH.png)
![image3](https://imgur.com/cryZKZh.png)
![image4](https://i.imgur.com/BSYQiXW.png)
![image5](https://i.imgur.com/cZmoHl9.png)

# Install

```js
npm
i
dbd - dark - dashboard
```

# Get help

Join our Discord Support Server

<a href="https://discord.gg/Nkc8MWxHRD"> <img src="https://discordapp.com/api/guilds/803034737261936670/widget.png" alt="Discord server"/></a>

# Documentation

Full and continuously updated project documentation can be found at the URL: https://docs.assistantscenter.com/discord-dashboard/v2/dark-theme/
# Privacy Policy and Terms of Use

You can always find an updated privacy policy and terms of use for discord-dashboard under
URL: https://assistantscenter.com/privacy-policy

# Contact

- **E-mail**: assistants.center@gmail.com, assistants.center.webmaster@gmail.com
- **Discord**: https://discord.gg/Nkc8MWxHRD

# Licenses

The project is covered by a **Shareware (CC BY-NC-SA 4.0) licence**. This means that the project is theoretically free
and limited, but it has a paid versions.

### What types of shareware license does the discord-dashboard project fall under?

- **OpenSource License**: Free. Personal usage only. Non-profit.
- **Personal License**: Profit allowed. Personal usage only. Priority support from developers. Limited to major version:
  v2.*
- **Production License**: Allowed for profit purposes. Distribution Allowed (you can share the license with your close
  friends). Priority support from developers. Limited to major version: v2.*

#### You always have the latest news and the option to purchase license at the URL: https://licenses.assistantscenter.com/

<hr>

© 2020-2022 Assistants Center, All rights reserved

==> dbd-dark-dashboard-1.6.592.tgz: package/README.md <==
![Banner](./DarkBanner.png)

<p align="center"><img src="https://nodei.co/npm/dbd-dark-dasboard.png"></p>
<p align="center"><a href="https://discord.gg/Nkc8MWxHRD"> <img src="https://discordapp.com/api/guilds/803034737261936670/widget.png" alt="Discord server"/></a></p>

# Discord-Dashboard Dark Theme

- Simple Discord-Dashboard theme
- Easy to customize
- Easy configuration
- Community support

# Preview

![image1](https://i.imgur.com/33sk9Gi.png)
![image2](https://imgur.com/2Lu0dtH.png)
![image3](https://imgur.com/cryZKZh.png)
![image4](https://i.imgur.com/BSYQiXW.png)
![image5](https://i.imgur.com/cZmoHl9.png)

# Install

```js
npm
i
dbd - dark - dashboard
```

# Get help

Join our Discord Support Server

<a href="https://discord.gg/Nkc8MWxHRD"> <img src="https://discordapp.com/api/guilds/803034737261936670/widget.png" alt="Discord server"/></a>

# Documentation

Full and continuously updated project documentation can be found at the URL: https://dbd-docs.assistantscenter.com/dark-theme/#/
# Privacy Policy and Terms of Use

You can always find an updated privacy policy and terms of use for discord-dashboard under
URL: https://assistantscenter.com/discord-dashboard-pp-tos/

# Contact

- **E-mail**: assistants.center@gmail.com, assistants.center.webmaster@gmail.com
- **Discord**: https://discord.gg/Nkc8MWxHRD

# Licenses

The project is covered by a **Shareware (CC BY-NC-SA 4.0) licence**. This means that the project is theoretically free
and limited, but it has a paid versions.

### What types of shareware license does the discord-dashboard project fall under?

- **OpenSource License**: Free. Personal usage only. Non-profit.
- **Personal License**: Profit allowed. Personal usage only. Priority support from developers. Limited to major version:
  v2.*
- **Production License**: Allowed for profit purposes. Distribution Allowed (you can share the license with your close
  friends). Priority support from developers. Limited to major version: v2.*

#### You always have the latest news and the option to purchase license at the URL: https://licenses.assistantscenter.com/

<hr>

© 2020-2022 Assistants Center, All rights reserved
